@@ -23,24 +23,18 @@
 #define KCOMBOBOX_H
 
 #include <kcompletion.h>
+
 #include <kcompletionbase.h>
 #include <kcompletion_export.h>
 
 #include <QComboBox>
 
+class KCompletionBox;
+class KComboBoxPrivate;
+
 class QLineEdit;
 class QMenu;
 
-class KCompletionBox;
-class QUrl;
-
-/*
- * ### KDE 5: On all methods that it is said that toDisplayString() will be used, it
- *            would be nice to add a flag to the method for forcing the pretty
- *            url or not. (ereslibre)
- * David: when would we want the ugly string rather than the pretty one? ;-)
- */
-
 /**
  * @short A combo box with completion support.
  *
@@ -150,10 +144,11 @@ class KCOMPLETION_EXPORT KComboBox : public QComboBox, public KCompletionBase //
 {
     Q_OBJECT
     Q_PROPERTY(bool autoCompletion READ autoCompletion WRITE setAutoCompletion)
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     Q_PROPERTY(bool urlDropsEnabled READ urlDropsEnabled WRITE setUrlDropsEnabled)
 #endif
     Q_PROPERTY(bool trapReturnKey READ trapReturnKey WRITE setTrapReturnKey)
+    Q_DECLARE_PRIVATE(KComboBox)
 
 public:
 
@@ -179,9 +174,9 @@ public:
 
     /**
      * Deprecated to reflect Qt api changes
-     * @deprecated
+     * @deprecated since 4.5
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     KCOMPLETION_DEPRECATED void insertURL(const QUrl &url, int index = -1)
     {
         insertUrl(index < 0 ? count() : index, url);
@@ -302,9 +297,9 @@ public:
     * menu.
     *
     * @param showMenu If @p true, show the context menu.
-    * @deprecated since 5.0, use setContextMenuPolicy instead
+    * @deprecated since 4.5, use setContextMenuPolicy instead
     */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     virtual KCOMPLETION_DEPRECATED void setContextMenuEnabled(bool showMenu);
 #endif
 
@@ -318,7 +313,7 @@ public:
      * @param enable If @p true, insert decoded URLs
      * @deprecated since 5.0. Use lineEdit()->installEventFilter with a LineEditUrlDropEventFilter
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     KCOMPLETION_DEPRECATED void setUrlDropsEnabled(bool enable);
 #endif
 
@@ -361,11 +356,6 @@ public:
      */
     bool trapReturnKey() const;
 
-    /**
-    * Re-implemented for internal reasons.  API not affected.
-    */
-    virtual bool eventFilter(QObject *, QEvent *);
-
     /**
      * @returns the completion box that is used in completion mode
      * CompletionPopup and CompletionPopupAuto.
@@ -459,9 +449,9 @@ Q_SIGNALS:
      * Note that you <em>must not</em> store the pointer to the QPopupMenu since it is
      * created and deleted on demand.  Otherwise, you can crash your app.
      *
-     * @param p the context menu about to be displayed
+     * @param contextMenu the context menu about to be displayed
      */
-    void aboutToShowContextMenu(QMenu *p);
+    void aboutToShowContextMenu(QMenu *contextMenu);
 
 public Q_SLOTS:
 
@@ -532,22 +522,11 @@ protected:
     */
     virtual void setCompletedText(const QString &text, bool marked);
 
-    virtual void wheelEvent(QWheelEvent *ev);
-
     virtual QSize minimumSizeHint() const;
 
-private Q_SLOTS:
-    void lineEditDeleted();
-
 private:
-    /**
-     * Initializes the variables upon construction.
-     */
-    void initWidget();
-
-private:
-    class KComboBoxPrivate;
-    KComboBoxPrivate *const d;
+    const QScopedPointer<KComboBoxPrivate> d_ptr;
+    Q_PRIVATE_SLOT(d_func(), void _k_lineEditDeleted())
 };
 
 #endif
